#!/usr/bin/env python
import os
import sys

import django
from django.conf import settings
from django.test.utils import get_runner

def runtests():
	os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.test_settings'
	django.setup()
	TestRunner = get_runner(settings)
	test_runner = TestRunner(verbosity=2)
	failures = test_runner.run_tests(["tests.__init__"])
	sys.exit(bool(failures))

if __name__ == "__main__":
	runtests()
